<?php

namespace Drupal\config_enforce;

use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Logger\LoggerChannelTrait;
use Drupal\config_enforce\EnforcedConfig;

/**
 * A registry of enforced configs for a given target module.
 */
class EnforcedConfigRegistry {

  use StringTranslationTrait, MessengerTrait, LoggerChannelTrait;

  // The machine name of the target module where this collection of enforced
  // configs is stored.
  protected $targetModule;

  // A logger service.
  protected $log;

  // A config factory.
  protected $configFactory;

  // An instance of the Drupal file system service.
  protected $fileSystem;

  /**
   * A basic constructor method.
   */
  public function __construct(string $target_module) {
    $this->log = $this->getLogger('config_enforce::EnforcedConfigRegistry');
    $this->configFactory = \Drupal::configFactory();
    $this->fileSystem = \Drupal::service('file_system');
    $this->setTargetModule($target_module);
  }

  /**
   * Set the target module for this enforced config.
   */
  public function setTargetModule(string $target_module) {
    $this->targetModule = $target_module;
    return $this;
  }

  /**
   * Return the target module for this enforced config.
   */
  public function getTargetModule() {
    return $this->targetModule;
  }

  /**
   * Return the config name for the target module.
   */
  public function getConfigName() {
    return EnforcedConfig::CONFIG_PREFIX . '.' . $this->getTargetModule();
  }

  /**
   * Return a list of all enforced config configs.
   */
  public static function getAllConfigNames() {
    return (new static(''))->getRegistryConfigNames();
  }

  /**
   * Return a list of all enforced config configs.
   */
  protected function getRegistryConfigNames() {
    return $this->configFactory->listAll(EnforcedConfig::CONFIG_PREFIX);
  }

}
