<?php

namespace Drupal\config_enforce;

use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Logger\LoggerChannelTrait;

/**
 * Create and manage a target module.
 */
class TargetModule {

  use StringTranslationTrait, MessengerTrait, LoggerChannelTrait;

  // The target module's human-readable name.
  protected $name;

  // The target module's machine-readable name.
  protected $machineName;

  // The target module's description.
  protected $description;

  // The path to which target modules should be written.
  protected $path;

  /**
   * A basic constructor method.
   */
  public function __construct() {
    $this->log = $this->getLogger('config_enforce::TargetModule');
  }

  /**
   * Set the target module's human-readable name.
   */
  public function setName(string $name) {
    $this->name = $name;
    return $this;
  }

  /**
   * Return the target module's human-readable name.
   */
  public function getName() {
    return $this->name;
  }

  /**
   * Set the target module's machine-readable name.
   */
  public function setMachineName(string $machine_name) {
    $this->machineName = $machine_name;
    return $this;
  }

  /**
   * Return the target module's machine-readable name.
   */
  public function getMachineName() {
    return $this->machineName;
  }

  /**
   * Set the target module's description.
   */
  public function setDescription(string $description) {
    $this->description = $description;
    return $this;
  }

  /**
   * Return the target module's description.
   */
  public function getDescription() {
    return $this->description;
  }

  /**
   * Set the path to which target modules should be written.
   */
  public function setPath(string $path) {
    $this->path = $path;
    return $this;
  }

  /**
   * Return the path to which target modules should be written.
   */
  public function getPath() {
    return $this->path;
  }

}
