<?php

namespace Drupal\config_enforce;

use Drupal\config_enforce\EnforcedConfig;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Logger\LoggerChannelTrait;

/**
 * A collection of all target modules.
 */
class TargetModuleCollection {

  use StringTranslationTrait, MessengerTrait, LoggerChannelTrait;

  // A logger service.
  protected $log;

  /**
   * A basic constructor method.
   */
  public function __construct() {
    $this->log = $this->getLogger('config_enforce::TargetModuleCollection');
  }

  /**
   * Return human-readable names for all target modules.
   */
  public function getTargetModuleLabels() {
    $modules = [];
    $available_modules = $this->getTargetModules();
    $available_modules = !is_null($available_modules) ? $available_modules : [];
    foreach ($available_modules as $module) {
      $modules[$module] = EnforcedConfig::getAllModules()[$module];
    }
    return $modules;
  }

  /**
   * Return a human-readable names for a target module.
   */
  public function getTargetModuleLabel(string $module) {
    return $this->getTargetModuleLabels()[$module];
  }

  /**
   * Return a list of available modules to target for writing config.
   */
  public function getTargetModules() {
    $target_modules = &drupal_static(__FUNCTION__);
    if (!isset($target_modules)) {
      $target_modules = [];
      foreach (EnforcedConfigRegistry::getAllConfigNames() as $registry_name) {
        $module = $this->getTargetModuleFromConfigName($registry_name);
        // Something is generating a phantom config (`config_enforce.enforced_configs.`)
        // @TODO remove this once we no longer get the spurious config.
        if (empty($module)) continue;
        $target_modules[] = $module;
      }
    }
    return $target_modules;
  }

  /**
   * Return the target module name, based on the registry's config name.
   */
  public function getTargetModuleFromConfigName($registry_name) {
    return substr($registry_name, strlen(EnforcedConfig::CONFIG_PREFIX) + 1);
  }

}
